==> matmflutterplugin-0.0.7.tar.gz: lib/MATMProvider.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:matmflutterplugin/matmflutterplugin.dart';
import 'package:android_intent/android_intent.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_appavailability/flutter_appavailability.dart';
import 'package:intent/extra.dart';
import 'package:store_redirect/store_redirect.dart';
import 'package:intent/intent.dart' as android_intent;
import 'package:intent/extra.dart' as android_extra;
import 'package:intent/typedExtra.dart' as android_typedExtra;
import 'package:intent/action.dart' as android_action;
class MATMProvider {
  BuildContext buildContext;
  var  mobileNo,agent_id,developer_id,password,partnerAgentId,clientTransactionId;
  MATMProvider(this.buildContext,this.mobileNo,this.agent_id,this.developer_id,this.password,this.partnerAgentId,this.clientTransactionId);
  Future<void> loadMATM(String mobileNos) {
    try {
      final AndroidIntent intent =  AndroidIntent(
        package: "com.microatm.services",
        componentName: 'com.microatm.services.Activities.MainActivity',
        action: 'action_view',
        arguments: <String, dynamic>{
          'mobileNo': mobileNo,
          'agent_id': agent_id,
          'developer_id': developer_id,
          'password':password,
          'partnerAgentId': partnerAgentId,
          'clientTransactionId': clientTransactionId,
        },
      );
      intent.launch();
    } catch (e) {
      showAppNotAvailableDialog(buildContext, "Please download mATM Service");
    }
  }
  showAppNotAvailableDialog(BuildContext context, String message) {
    // set up the buttons

    Widget launchButton = FlatButton(
      child: Text("Download  Service"),
      onPressed: () {
        StoreRedirect.redirect(
            androidAppId: "com.microatm.services", iOSAppId: "");
        Navigator.pop(context);
      },
    );

    Widget closeButton = FlatButton(
      child: Text("Cancel"),
      onPressed: () {
        Navigator.pop(context);
      },
    );
    // set up the AlertDialog
    AlertDialog alert = AlertDialog(
      content: Text(message),
      actions: [launchButton, closeButton],
    );

    // show the dialog
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return alert;
      },
    );
  }
}

==> matmflutterplugin-0.0.8.tar.gz: lib/MATMProvider.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:matmflutterplugin/matmflutterplugin.dart';
import 'package:android_intent/android_intent.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_appavailability/flutter_appavailability.dart';
import 'package:intent/extra.dart';
import 'package:store_redirect/store_redirect.dart';
import 'package:intent/intent.dart' as android_intent;
import 'package:intent/extra.dart' as android_extra;
import 'package:intent/typedExtra.dart' as android_typedExtra;
import 'package:intent/action.dart' as android_action;
class MATMProvider {
  BuildContext buildContext;
  var  mobileNo,agent_id,developer_id,password,partnerAgentId,clientTransactionId;
  MATMProvider(this.buildContext,this.mobileNo,this.agent_id,this.developer_id,this.password,this.partnerAgentId,this.clientTransactionId);
  Future<void> loadMATM() {
    try {
      final AndroidIntent intent =  AndroidIntent(
        package: "com.microatm.services",
        componentName: 'com.microatm.services.Activities.MainActivity',
        action: 'action_view',
        arguments: <String, dynamic>{
          'mobileNo': mobileNo,
          'agent_id': agent_id,
          'developer_id': developer_id,
          'password':password,
          'partnerAgentId': partnerAgentId,
          'clientTransactionId': clientTransactionId,
        },
      );
      intent.launch();
    } catch (e) {
      showAppNotAvailableDialog(buildContext, "Please download mATM Service");
    }
  }
  showAppNotAvailableDialog(BuildContext context, String message) {
    // set up the buttons

    Widget launchButton = FlatButton(
      child: Text("Download  Service"),
      onPressed: () {
        StoreRedirect.redirect(
            androidAppId: "com.microatm.services", iOSAppId: "");
        Navigator.pop(context);
      },
    );

    Widget closeButton = FlatButton(
      child: Text("Cancel"),
      onPressed: () {
        Navigator.pop(context);
      },
    );
    // set up the AlertDialog
    AlertDialog alert = AlertDialog(
      content: Text(message),
      actions: [launchButton, closeButton],
    );

    // show the dialog
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return alert;
      },
    );
  }
}
